import {
  Body,
  Controller,
  Get,
  Inject,
  Param,
  Post,
} from '@midwayjs/core';
import { RF } from '../response/CustomerResponse';
import { Page, Query } from '../decorator/page.decorator';
import { QuestionService } from '../service/question.service';
import { Opera } from '../frame/dbOpera';
import { get } from 'lodash';
import dayjs = require('dayjs');

@Controller('/question')
export class QuestionController {
  @Inject()
  service: QuestionService;

  @Post('/')
  async create(@Body() body) {
    const data = await this.service.create(body);
    return RF.success(data);
  }

  @Get('/')
  async query(@Query() query, @Page() page) {
    // 该表没有id.所以需要重新声明查询排序列
    const meta = { order: { created_time: 'DESC' }, ...page }
    // 时间,传来的是单日期.需要获取当天开始与结束的时分秒,然后范围查询
    const operas = {
      created_time: Opera.Between,
      deal_time: Opera.Between
    }
    const created_time = get(query, 'created_time');
    if (created_time) {
      const timeArr = []
      timeArr.push(dayjs(created_time).format('YYYY-MM-DD 00:00:00'))
      timeArr.push(dayjs(created_time).format('YYYY-MM-DD 23:59:59'))
      query['created_time'] = timeArr
    }
    const deal_time = get(query, 'deal_time');
    if (deal_time) {
      const timeArr = []
      timeArr.push(dayjs(deal_time).format('YYYY-MM-DD 00:00:00'))
      timeArr.push(dayjs(deal_time).format('YYYY-MM-DD 23:59:59'))
      query['deal_time'] = timeArr
    }
    const result = await this.service.query(query, meta, operas);
    return RF.success(result);
  }

  @Get('/:id')
  async fetch(@Param('id') question_id: number) {
    const result = await this.service.fetch({ question_id });
    return RF.success(result);
  }

  @Post('/:id')
  async update(@Param('id') question_id: number, @Body() body) {
    const result = await this.service.update({ question_id }, body);
    return RF.success(result);
  }

  // @Del('/:id')
  // async delete(@Param('id') id: number) {
  //   await this.service.delete({ id });
  //   return RF.success();
  // }
}
