import dayjs = require('dayjs');
import { Column, CreateDateColumn, Entity, PrimaryGeneratedColumn, UpdateDateColumn, VersionColumn } from 'typeorm';

@Entity('question', { comment: '投诉与建议' })
export class Question {
  /**数据id */
  @PrimaryGeneratedColumn({ type: 'integer' })
  question_id: number;
  /**数据创建时间 */
  @CreateDateColumn({ type: 'timestamp', transformer: { from: value => (value ? dayjs(value).format('YYYY-MM-DD HH:mm:ss') : value), to: value => value } })
  created_time?: Date;
  /**数据最后更新时间 */
  @UpdateDateColumn({ type: 'timestamp', transformer: { from: value => (value ? dayjs(value).format('YYYY-MM-DD HH:mm:ss') : value), to: value => value } })
  update_time?: Date;
  /**数据版本 */
  @VersionColumn({ type: 'integer', default: 1 })
  __v?: number;

  @Column({ comment: '问题类型: 1-投诉反馈; 2-意见建议; 3-咨询反馈' })
  type: string;
  @Column({ comment: '姓名' })
  name: string;
  @Column({ comment: '电话' })
  phone: string;
  @Column({ comment: '邮箱' })
  email: string;
  @Column({ comment: '街/路' })
  street: string;
  @Column({ comment: '小区' })
  community: string;
  @Column({ comment: '楼栋' })
  building: string;
  @Column({ comment: '单元' })
  unit: string;
  @Column({ comment: '室' })
  room: string;
  @Column({ comment: '地址' })
  address: string;
  @Column({ comment: '反馈详情' })
  description: string;
  @Column({ comment: '处理反馈' })
  deal_desc: string;
  @Column({ comment: '处理状态: 0-未处理;1-已处理', default: '0' })
  deal_status: string
  @Column({ type: 'timestamp', nullable: true, transformer: { from: value => (value ? dayjs(value).format('YYYY-MM-DD HH:mm:ss') : value), to: value => value }, comment: '处理时间' })
  deal_time: Date;
}
